@@ -94,6 +94,7 @@ OC.L10N.register(
     "Delete message" : "Выдаліць паведамленне",
     "More actions" : "Больш дзеянняў",
     "Back" : "Назад",
+    "Create task" : "Стварыць заданне",
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне"],
     "Mark as unread" : "Пазначыць як непрачытанае",
     "Mark as read" : "Пазначыць як прачытанае",
@@ -119,6 +120,7 @@ OC.L10N.register(
     "Forward message as attachment" : "Пераслаць паведамленне як далучэнне",
     "Unnamed" : "Без назвы",
     "Download Zip" : "Спампаваць Zip",
+    "Quoted text" : "Цытаваны тэкст",
     "Move" : "Перамясціць",
     "Used quota: {quota}% ({limit})" : "Выкарыстана квота: {quota}% ({limit})",
     "Used quota: {quota}%" : "Выкарыстана квота: {quota}%",
@@ -163,6 +165,9 @@ OC.L10N.register(
     "Tags" : "Тэгі",
     "Last 7 days" : "Апошнія 7 дзён",
     "Custom" : "Карыстальніцкі",
+    "Task created" : "Заданне створана",
+    "Could not create task" : "Не ўдалося стварыць заданне",
+    "No calendars with task list support" : "Няма календароў з падтрымкай спісаў заднняў",
     "Not found" : "Не знойдзена",
     "Newest message" : "Апошняе паведамленне",
     "Please select languages to translate to and from" : "Выберыце, з якой мовы на якую перакладаць",
