@@ -115,7 +115,6 @@ OC.L10N.register(
     "Cancel" : "Katkesta",
     "Search in the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
     "Activate" : "Lülita sisse",
-    "Put my text to the bottom of a reply instead of on top of it." : "Sisesta minu tekst vastuse alla, mitte tema kohale",
     "Mark as important" : "Märgi oluliseks",
     "Remind about messages that require a reply but received none" : "Tuleta mulle meelde kirju, mis eeldavad vastust, kui pole seda veel saanud",
     "Use internal addresses" : "Kasuta sisemisi aadresse",
@@ -127,16 +126,14 @@ OC.L10N.register(
     "General" : "Üldine",
     "Layout" : "Välimus",
     "List" : "Nimekiri",
-    "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
-    "Message View Mode" : "Kirjade vaate liik",
-    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
-    "Show only the selected message" : "Näita vaid valitud kirja",
     "Sorting" : "Järjestus",
     "Newest" : "Uusim",
     "Oldest" : "Vanim",
-    "Search in body" : "Otsi kirja sisust",
+    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
+    "Show only the selected message" : "Näita vaid valitud kirja",
     "Reply text position" : "Vastuse teksti asukoht",
+    "Search in body" : "Otsi kirja sisust",
     "Gravatar settings" : "Gravatari seadistused",
     "Use Gravatar and favicon avatars" : "Kasuta Gravatari ja favikonide tunnuspilte",
     "Mailto" : "Mailto",
@@ -707,6 +704,7 @@ OC.L10N.register(
     "For more details, please click here to open our documentation." : "Lisateavet leiad meie dokumentatsioonist ↗.",
     "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
     "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
+    "Message View Mode" : "Kirjade vaate liik",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Algne kiri lisatakse manusena „message/rfc822“ tüüpi failina.",
     "\"Mark as Spam\" Email Address" : "„Märgitud rämpspostiks“ e-posti aadressid",
     "\"Mark Not Junk\" Email Address" : "„Pole rämpspost“ e-posti aadressid",
@@ -823,6 +821,8 @@ OC.L10N.register(
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
-    "Continue to %s" : "Jätka siia: %s"
+    "Continue to %s" : "Jätka siia: %s",
+    "Put my text to the bottom of a reply instead of on top of it." : "Sisesta minu tekst vastuse alla, mitte tema kohale",
+    "Vertical split" : "Püstjoones jagamine"
 },
 "nplurals=2; plural=(n != 1);");
