@@ -58,7 +58,6 @@ OC.L10N.register(
     "Add alias" : "Dodaj pseudonim",
     "Create alias" : "Stvori pseudonim",
     "Cancel" : "Odustani",
-    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
     "Could not update preference" : "Ažuriranje postavki nije uspjelo",
     "Accounts" : "Korisnićki računi",
     "Add mail account" : "Dodaj račun e-pošte",
@@ -386,6 +385,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s"
+    "Continue to %s" : "Idi do %s",
+    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
